==> vtk-8.1.0-3-armv6h.pkg.tar.xz: vtk/vtkColorTransferFunction.java <==
// java wrapper for vtkColorTransferFunction object
//

package vtk;
import vtk.*;

public class vtkColorTransferFunction extends vtkScalarsToColors
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void DeepCopy_2(vtkScalarsToColors id0);
  public void DeepCopy(vtkScalarsToColors id0)
    { DeepCopy_2(id0); }

  private native void ShallowCopy_3(vtkColorTransferFunction id0);
  public void ShallowCopy(vtkColorTransferFunction id0)
    { ShallowCopy_3(id0); }

  private native int GetSize_4();
  public int GetSize()
    { return GetSize_4(); }

  private native int AddRGBPoint_5(double id0,double id1,double id2,double id3);
  public int AddRGBPoint(double id0,double id1,double id2,double id3)
    { return AddRGBPoint_5(id0,id1,id2,id3); }

  private native int AddRGBPoint_6(double id0,double id1,double id2,double id3,double id4,double id5);
  public int AddRGBPoint(double id0,double id1,double id2,double id3,double id4,double id5)
    { return AddRGBPoint_6(id0,id1,id2,id3,id4,id5); }

  private native int AddHSVPoint_7(double id0,double id1,double id2,double id3);
  public int AddHSVPoint(double id0,double id1,double id2,double id3)
    { return AddHSVPoint_7(id0,id1,id2,id3); }

  private native int AddHSVPoint_8(double id0,double id1,double id2,double id3,double id4,double id5);
  public int AddHSVPoint(double id0,double id1,double id2,double id3,double id4,double id5)
    { return AddHSVPoint_8(id0,id1,id2,id3,id4,id5); }

  private native int RemovePoint_9(double id0);
  public int RemovePoint(double id0)
    { return RemovePoint_9(id0); }

  private native void AddRGBSegment_10(double id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7);
  public void AddRGBSegment(double id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7)
    { AddRGBSegment_10(id0,id1,id2,id3,id4,id5,id6,id7); }

  private native void AddHSVSegment_11(double id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7);
  public void AddHSVSegment(double id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7)
    { AddHSVSegment_11(id0,id1,id2,id3,id4,id5,id6,id7); }

  private native void RemoveAllPoints_12();
  public void RemoveAllPoints()
    { RemoveAllPoints_12(); }

  private native double[] GetColor_13(double id0);
  public double[] GetColor(double id0)
    { return GetColor_13(id0); }

  private native void GetColor_14(double id0,double id1[]);
  public void GetColor(double id0,double id1[])
    { GetColor_14(id0,id1); }

  private native double GetRedValue_15(double id0);
  public double GetRedValue(double id0)
    { return GetRedValue_15(id0); }

  private native double GetGreenValue_16(double id0);
  public double GetGreenValue(double id0)
    { return GetGreenValue_16(id0); }

  private native double GetBlueValue_17(double id0);
  public double GetBlueValue(double id0)
    { return GetBlueValue_17(id0); }

  private native int GetNodeValue_18(int id0,double id1[]);
  public int GetNodeValue(int id0,double id1[])
    { return GetNodeValue_18(id0,id1); }

  private native int SetNodeValue_19(int id0,double id1[]);
  public int SetNodeValue(int id0,double id1[])
    { return SetNodeValue_19(id0,id1); }

  private native double[] GetRange_20();
  public double[] GetRange()
    { return GetRange_20(); }

  private native void GetRange_21(double id0[]);
  public void GetRange(double id0[])
    { GetRange_21(id0); }

  private native int AdjustRange_22(double id0[]);
  public int AdjustRange(double id0[])
    { return AdjustRange_22(id0); }

  private native void SetClamping_23(int id0);
  public void SetClamping(int id0)
    { SetClamping_23(id0); }

  private native int GetClampingMinValue_24();
  public int GetClampingMinValue()
    { return GetClampingMinValue_24(); }

  private native int GetClampingMaxValue_25();
  public int GetClampingMaxValue()
    { return GetClampingMaxValue_25(); }

  private native int GetClamping_26();
  public int GetClamping()
    { return GetClamping_26(); }

  private native void ClampingOn_27();
  public void ClampingOn()
    { ClampingOn_27(); }

  private native void ClampingOff_28();
  public void ClampingOff()
    { ClampingOff_28(); }

  private native void SetColorSpace_29(int id0);
  public void SetColorSpace(int id0)
    { SetColorSpace_29(id0); }

  private native int GetColorSpaceMinValue_30();
  public int GetColorSpaceMinValue()
    { return GetColorSpaceMinValue_30(); }

  private native int GetColorSpaceMaxValue_31();
  public int GetColorSpaceMaxValue()
    { return GetColorSpaceMaxValue_31(); }

  private native void SetColorSpaceToRGB_32();
  public void SetColorSpaceToRGB()
    { SetColorSpaceToRGB_32(); }

  private native void SetColorSpaceToHSV_33();
  public void SetColorSpaceToHSV()
    { SetColorSpaceToHSV_33(); }

  private native void SetColorSpaceToLab_34();
  public void SetColorSpaceToLab()
    { SetColorSpaceToLab_34(); }

  private native void SetColorSpaceToLabCIEDE2000_35();
  public void SetColorSpaceToLabCIEDE2000()
    { SetColorSpaceToLabCIEDE2000_35(); }

  private native void SetColorSpaceToDiverging_36();
  public void SetColorSpaceToDiverging()
    { SetColorSpaceToDiverging_36(); }

  private native int GetColorSpace_37();
  public int GetColorSpace()
    { return GetColorSpace_37(); }

  private native void SetHSVWrap_38(int id0);
  public void SetHSVWrap(int id0)
    { SetHSVWrap_38(id0); }

  private native int GetHSVWrap_39();
  public int GetHSVWrap()
    { return GetHSVWrap_39(); }

  private native void HSVWrapOn_40();
  public void HSVWrapOn()
    { HSVWrapOn_40(); }

  private native void HSVWrapOff_41();
  public void HSVWrapOff()
    { HSVWrapOff_41(); }

  private native void SetScale_42(int id0);
  public void SetScale(int id0)
    { SetScale_42(id0); }

  private native void SetScaleToLinear_43();
  public void SetScaleToLinear()
    { SetScaleToLinear_43(); }

  private native void SetScaleToLog10_44();
  public void SetScaleToLog10()
    { SetScaleToLog10_44(); }

  private native int GetScale_45();
  public int GetScale()
    { return GetScale_45(); }

  private native void SetNanColor_46(double id0,double id1,double id2);
  public void SetNanColor(double id0,double id1,double id2)
    { SetNanColor_46(id0,id1,id2); }

  private native void SetNanColor_47(double id0[]);
  public void SetNanColor(double id0[])
    { SetNanColor_47(id0); }

  private native double[] GetNanColor_48();
  public double[] GetNanColor()
    { return GetNanColor_48(); }

  private native void SetBelowRangeColor_49(double id0,double id1,double id2);
  public void SetBelowRangeColor(double id0,double id1,double id2)
    { SetBelowRangeColor_49(id0,id1,id2); }

  private native void SetBelowRangeColor_50(double id0[]);
  public void SetBelowRangeColor(double id0[])
    { SetBelowRangeColor_50(id0); }

  private native double[] GetBelowRangeColor_51();
  public double[] GetBelowRangeColor()
    { return GetBelowRangeColor_51(); }

  private native void SetUseBelowRangeColor_52(int id0);
  public void SetUseBelowRangeColor(int id0)
    { SetUseBelowRangeColor_52(id0); }

  private native int GetUseBelowRangeColor_53();
  public int GetUseBelowRangeColor()
    { return GetUseBelowRangeColor_53(); }

  private native void UseBelowRangeColorOn_54();
  public void UseBelowRangeColorOn()
    { UseBelowRangeColorOn_54(); }

  private native void UseBelowRangeColorOff_55();
  public void UseBelowRangeColorOff()
    { UseBelowRangeColorOff_55(); }

  private native void SetAboveRangeColor_56(double id0,double id1,double id2);
  public void SetAboveRangeColor(double id0,double id1,double id2)
    { SetAboveRangeColor_56(id0,id1,id2); }

  private native void SetAboveRangeColor_57(double id0[]);
  public void SetAboveRangeColor(double id0[])
    { SetAboveRangeColor_57(id0); }

  private native double[] GetAboveRangeColor_58();
  public double[] GetAboveRangeColor()
    { return GetAboveRangeColor_58(); }

  private native void SetUseAboveRangeColor_59(int id0);
  public void SetUseAboveRangeColor(int id0)
    { SetUseAboveRangeColor_59(id0); }

  private native int GetUseAboveRangeColor_60();
  public int GetUseAboveRangeColor()
    { return GetUseAboveRangeColor_60(); }

  private native void UseAboveRangeColorOn_61();
  public void UseAboveRangeColorOn()
    { UseAboveRangeColorOn_61(); }

  private native void UseAboveRangeColorOff_62();
  public void UseAboveRangeColorOff()
    { UseAboveRangeColorOff_62(); }

  private native void SetAllowDuplicateScalars_63(int id0);
  public void SetAllowDuplicateScalars(int id0)
    { SetAllowDuplicateScalars_63(id0); }

  private native int GetAllowDuplicateScalars_64();
  public int GetAllowDuplicateScalars()
    { return GetAllowDuplicateScalars_64(); }

  private native void AllowDuplicateScalarsOn_65();
  public void AllowDuplicateScalarsOn()
    { AllowDuplicateScalarsOn_65(); }

  private native void AllowDuplicateScalarsOff_66();
  public void AllowDuplicateScalarsOff()
    { AllowDuplicateScalarsOff_66(); }

  private native int GetNumberOfAvailableColors_67();
  public int GetNumberOfAvailableColors()
    { return GetNumberOfAvailableColors_67(); }

  private native void GetIndexedColor_68(int id0,double id1[]);
  public void GetIndexedColor(int id0,double id1[])
    { GetIndexedColor_68(id0,id1); }

  public vtkColorTransferFunction() { super(); }

  public vtkColorTransferFunction(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv6h.pkg.tar.xz: vtk/vtkColorTransferFunction.java <==
// java wrapper for vtkColorTransferFunction object
//

package vtk;
import vtk.*;

public class vtkColorTransferFunction extends vtkScalarsToColors
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void DeepCopy_2(vtkScalarsToColors id0);
  public void DeepCopy(vtkScalarsToColors id0)
    { DeepCopy_2(id0); }

  private native void ShallowCopy_3(vtkColorTransferFunction id0);
  public void ShallowCopy(vtkColorTransferFunction id0)
    { ShallowCopy_3(id0); }

  private native int GetSize_4();
  public int GetSize()
    { return GetSize_4(); }

  private native int AddRGBPoint_5(double id0,double id1,double id2,double id3);
  public int AddRGBPoint(double id0,double id1,double id2,double id3)
    { return AddRGBPoint_5(id0,id1,id2,id3); }

  private native int AddRGBPoint_6(double id0,double id1,double id2,double id3,double id4,double id5);
  public int AddRGBPoint(double id0,double id1,double id2,double id3,double id4,double id5)
    { return AddRGBPoint_6(id0,id1,id2,id3,id4,id5); }

  private native int AddHSVPoint_7(double id0,double id1,double id2,double id3);
  public int AddHSVPoint(double id0,double id1,double id2,double id3)
    { return AddHSVPoint_7(id0,id1,id2,id3); }

  private native int AddHSVPoint_8(double id0,double id1,double id2,double id3,double id4,double id5);
  public int AddHSVPoint(double id0,double id1,double id2,double id3,double id4,double id5)
    { return AddHSVPoint_8(id0,id1,id2,id3,id4,id5); }

  private native int RemovePoint_9(double id0);
  public int RemovePoint(double id0)
    { return RemovePoint_9(id0); }

  private native void AddRGBSegment_10(double id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7);
  public void AddRGBSegment(double id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7)
    { AddRGBSegment_10(id0,id1,id2,id3,id4,id5,id6,id7); }

  private native void AddHSVSegment_11(double id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7);
  public void AddHSVSegment(double id0,double id1,double id2,double id3,double id4,double id5,double id6,double id7)
    { AddHSVSegment_11(id0,id1,id2,id3,id4,id5,id6,id7); }

  private native void RemoveAllPoints_12();
  public void RemoveAllPoints()
    { RemoveAllPoints_12(); }

  private native double[] GetColor_13(double id0);
  public double[] GetColor(double id0)
    { return GetColor_13(id0); }

  private native void GetColor_14(double id0,double id1[]);
  public void GetColor(double id0,double id1[])
    { GetColor_14(id0,id1); }

  private native double GetRedValue_15(double id0);
  public double GetRedValue(double id0)
    { return GetRedValue_15(id0); }

  private native double GetGreenValue_16(double id0);
  public double GetGreenValue(double id0)
    { return GetGreenValue_16(id0); }

  private native double GetBlueValue_17(double id0);
  public double GetBlueValue(double id0)
    { return GetBlueValue_17(id0); }

  private native int GetNodeValue_18(int id0,double id1[]);
  public int GetNodeValue(int id0,double id1[])
    { return GetNodeValue_18(id0,id1); }

  private native int SetNodeValue_19(int id0,double id1[]);
  public int SetNodeValue(int id0,double id1[])
    { return SetNodeValue_19(id0,id1); }

  private native double[] GetRange_20();
  public double[] GetRange()
    { return GetRange_20(); }

  private native void GetRange_21(double id0[]);
  public void GetRange(double id0[])
    { GetRange_21(id0); }

  private native int AdjustRange_22(double id0[]);
  public int AdjustRange(double id0[])
    { return AdjustRange_22(id0); }

  private native void SetClamping_23(int id0);
  public void SetClamping(int id0)
    { SetClamping_23(id0); }

  private native int GetClampingMinValue_24();
  public int GetClampingMinValue()
    { return GetClampingMinValue_24(); }

  private native int GetClampingMaxValue_25();
  public int GetClampingMaxValue()
    { return GetClampingMaxValue_25(); }

  private native int GetClamping_26();
  public int GetClamping()
    { return GetClamping_26(); }

  private native void ClampingOn_27();
  public void ClampingOn()
    { ClampingOn_27(); }

  private native void ClampingOff_28();
  public void ClampingOff()
    { ClampingOff_28(); }

  private native void SetColorSpace_29(int id0);
  public void SetColorSpace(int id0)
    { SetColorSpace_29(id0); }

  private native int GetColorSpaceMinValue_30();
  public int GetColorSpaceMinValue()
    { return GetColorSpaceMinValue_30(); }

  private native int GetColorSpaceMaxValue_31();
  public int GetColorSpaceMaxValue()
    { return GetColorSpaceMaxValue_31(); }

  private native void SetColorSpaceToRGB_32();
  public void SetColorSpaceToRGB()
    { SetColorSpaceToRGB_32(); }

  private native void SetColorSpaceToHSV_33();
  public void SetColorSpaceToHSV()
    { SetColorSpaceToHSV_33(); }

  private native void SetColorSpaceToLab_34();
  public void SetColorSpaceToLab()
    { SetColorSpaceToLab_34(); }

  private native void SetColorSpaceToLabCIEDE2000_35();
  public void SetColorSpaceToLabCIEDE2000()
    { SetColorSpaceToLabCIEDE2000_35(); }

  private native void SetColorSpaceToDiverging_36();
  public void SetColorSpaceToDiverging()
    { SetColorSpaceToDiverging_36(); }

  private native void SetColorSpaceToStep_37();
  public void SetColorSpaceToStep()
    { SetColorSpaceToStep_37(); }

  private native int GetColorSpace_38();
  public int GetColorSpace()
    { return GetColorSpace_38(); }

  private native void SetHSVWrap_39(int id0);
  public void SetHSVWrap(int id0)
    { SetHSVWrap_39(id0); }

  private native int GetHSVWrap_40();
  public int GetHSVWrap()
    { return GetHSVWrap_40(); }

  private native void HSVWrapOn_41();
  public void HSVWrapOn()
    { HSVWrapOn_41(); }

  private native void HSVWrapOff_42();
  public void HSVWrapOff()
    { HSVWrapOff_42(); }

  private native void SetScale_43(int id0);
  public void SetScale(int id0)
    { SetScale_43(id0); }

  private native void SetScaleToLinear_44();
  public void SetScaleToLinear()
    { SetScaleToLinear_44(); }

  private native void SetScaleToLog10_45();
  public void SetScaleToLog10()
    { SetScaleToLog10_45(); }

  private native int GetScale_46();
  public int GetScale()
    { return GetScale_46(); }

  private native void SetNanColor_47(double id0,double id1,double id2);
  public void SetNanColor(double id0,double id1,double id2)
    { SetNanColor_47(id0,id1,id2); }

  private native void SetNanColor_48(double id0[]);
  public void SetNanColor(double id0[])
    { SetNanColor_48(id0); }

  private native double[] GetNanColor_49();
  public double[] GetNanColor()
    { return GetNanColor_49(); }

  private native void SetNanOpacity_50(double id0);
  public void SetNanOpacity(double id0)
    { SetNanOpacity_50(id0); }

  private native double GetNanOpacity_51();
  public double GetNanOpacity()
    { return GetNanOpacity_51(); }

  private native void SetNanColorRGBA_52(double id0,double id1,double id2,double id3);
  public void SetNanColorRGBA(double id0,double id1,double id2,double id3)
    { SetNanColorRGBA_52(id0,id1,id2,id3); }

  private native void SetNanColorRGBA_53(double id0[]);
  public void SetNanColorRGBA(double id0[])
    { SetNanColorRGBA_53(id0); }

  private native void SetBelowRangeColor_54(double id0,double id1,double id2);
  public void SetBelowRangeColor(double id0,double id1,double id2)
    { SetBelowRangeColor_54(id0,id1,id2); }

  private native void SetBelowRangeColor_55(double id0[]);
  public void SetBelowRangeColor(double id0[])
    { SetBelowRangeColor_55(id0); }

  private native double[] GetBelowRangeColor_56();
  public double[] GetBelowRangeColor()
    { return GetBelowRangeColor_56(); }

  private native void SetUseBelowRangeColor_57(int id0);
  public void SetUseBelowRangeColor(int id0)
    { SetUseBelowRangeColor_57(id0); }

  private native int GetUseBelowRangeColor_58();
  public int GetUseBelowRangeColor()
    { return GetUseBelowRangeColor_58(); }

  private native void UseBelowRangeColorOn_59();
  public void UseBelowRangeColorOn()
    { UseBelowRangeColorOn_59(); }

  private native void UseBelowRangeColorOff_60();
  public void UseBelowRangeColorOff()
    { UseBelowRangeColorOff_60(); }

  private native void SetAboveRangeColor_61(double id0,double id1,double id2);
  public void SetAboveRangeColor(double id0,double id1,double id2)
    { SetAboveRangeColor_61(id0,id1,id2); }

  private native void SetAboveRangeColor_62(double id0[]);
  public void SetAboveRangeColor(double id0[])
    { SetAboveRangeColor_62(id0); }

  private native double[] GetAboveRangeColor_63();
  public double[] GetAboveRangeColor()
    { return GetAboveRangeColor_63(); }

  private native void SetUseAboveRangeColor_64(int id0);
  public void SetUseAboveRangeColor(int id0)
    { SetUseAboveRangeColor_64(id0); }

  private native int GetUseAboveRangeColor_65();
  public int GetUseAboveRangeColor()
    { return GetUseAboveRangeColor_65(); }

  private native void UseAboveRangeColorOn_66();
  public void UseAboveRangeColorOn()
    { UseAboveRangeColorOn_66(); }

  private native void UseAboveRangeColorOff_67();
  public void UseAboveRangeColorOff()
    { UseAboveRangeColorOff_67(); }

  private native void SetAllowDuplicateScalars_68(int id0);
  public void SetAllowDuplicateScalars(int id0)
    { SetAllowDuplicateScalars_68(id0); }

  private native int GetAllowDuplicateScalars_69();
  public int GetAllowDuplicateScalars()
    { return GetAllowDuplicateScalars_69(); }

  private native void AllowDuplicateScalarsOn_70();
  public void AllowDuplicateScalarsOn()
    { AllowDuplicateScalarsOn_70(); }

  private native void AllowDuplicateScalarsOff_71();
  public void AllowDuplicateScalarsOff()
    { AllowDuplicateScalarsOff_71(); }

  private native int GetNumberOfAvailableColors_72();
  public int GetNumberOfAvailableColors()
    { return GetNumberOfAvailableColors_72(); }

  private native void GetIndexedColor_73(int id0,double id1[]);
  public void GetIndexedColor(int id0,double id1[])
    { GetIndexedColor_73(id0,id1); }

  public vtkColorTransferFunction() { super(); }

  public vtkColorTransferFunction(long id) { super(id); }
  public native long   VTKInit();

}
